@@ -200,20 +200,6 @@ sub Extends {
 
 ################################################################################
 
-sub GlobExtends {
-    my ($glob, %methods) = @_;
-    my $package = ref $glob || 'main';
-
-    no strict 'refs';
-    for my $name (keys %methods) {
-        *{"${package}::$name"} = $methods{$name};
-    }
-
-    return $glob;
-}
-
-################################################################################
-
 =head2 Alias($object, $existing_method, $new_name)
 
 Creates an alias for an existing method in the object with a new name.
@@ -1160,6 +1146,109 @@ sub Unload {
 
     ############################################################################
 
+=head2 Creating an STDERR Logger with decorative functionalities
+
+    use strict;
+    use warnings;
+    use Time::Piece;
+
+    ############################################################################
+    # BaseLogger.pm
+    package BaseLogger;
+    use strict;
+    use warnings;
+
+    sub new {
+        my $class = shift;
+        return bless {}, $class;
+    }
+
+    sub log {
+        my ($self, $message) = @_;
+        print STDERR $message;
+    }
+
+    1;
+
+    ############################################################################
+    # LoggerDecorators.pm
+    package LoggerDecorators;
+
+    use strict;
+    use warnings;
+    use Time::Piece;
+
+    # Timestamp decorator
+    sub add_timestamp {
+        my ($logger) = @_;
+        return sub {
+            my ($self, $message) = @_;
+            my $timestamp = localtime->strftime('%Y-%m-%d %H:%M:%S');
+            $logger->($self, "[$timestamp] $message");
+        };
+    }
+
+    # Log level decorator
+    sub add_log_level {
+        my ($logger, $level) = @_;
+        return sub {
+            my ($self, $message) = @_;
+            $logger->($self, "[$level] $message");
+        };
+    }
+
+    1;
+
+    ############################################################################
+    # Example.pl
+
+    package main;
+    use strict;
+    use warnings;
+    use BaseLogger;
+    use LoggerDecorators;
+
+    # Create an instance of BaseLogger
+    my $logger = BaseLogger->new();
+
+    # Create a decorated logger
+    my $decorated_logger = sub {
+        my ($self, $message) = @_;
+        $logger->log($message);
+    };
+
+    # Apply decorators to extend logging functionality
+    $decorated_logger = add_timestamp($decorated_logger);
+    $decorated_logger = add_log_level($decorated_logger, 'INFO');
+
+    # Helper function to capture STDERR output
+    sub capture_stderr {
+        my ($code) = @_;
+        my $output;
+        {
+            open my $stderr_backup, '>&', STDERR or die "Cannot backup STDERR: $!";
+            open STDERR, '>', \$output or die "Cannot redirect STDERR: $!";
+            
+            $code->();
+            
+            open STDERR, '>&', $stderr_backup or die "Cannot restore STDERR: $!";
+            close $stderr_backup;
+        }
+        return $output;
+    }
+
+    # Capture logging output
+    my $stderr_output = capture_stderr(sub {
+        $decorated_logger->("This is a test message\n");
+    });
+
+    # Output captured log
+    print "Captured STDERR output:\n";
+    print $stderr_output;
+
+    1;
+
+
 =cut
 
 ################################################################################
